@@ -175,7 +175,7 @@ def path(path_elements):
     if isinstance(path_elements, STR):
         path_elements = [path_elements]
 
-    # Concatenate elements and seperate with /
+    # Concatenate elements and separate with /
     for i in path_elements:
         pathname += i + '/'
 
@@ -331,13 +331,12 @@ def create_overlay_dict(**kwargs):
     """
     result = {
         'name': '',
-        'owner_name': '',
-        'owner_email': '',
+        'owner': [],
         'homepage': '',
         'irc': '',
-        'description': '',
-        'feeds': [],
-        'sources': [('','','')],
+        'description': [],
+        'feed': [],
+        'source': [('','','')],
         'priority': 50,
         'quality': 'experimental',
         'status': '',
